/******************************************************************************
*                                                                             *
*                                                                             *
*                                                                             *
*                                 Copyright by                                *
*                                                                             *
*                               Azoteq (Pty) Ltd                              *
*                           Republic of South Africa                          *
*                                                                             *
*                            Tel: +27(0)21 863 0033                           *
*                                 www.azoteq.com                              *
*                                                                             *
*******************************************************************************
*  Refer to IQS7222D datasheet for more information, available here:          *
*  - https://www.azoteq.com/design/datasheets/                                *
*******************************************************************************
*                       IQS7222D - Registers & Memory Map                     *
*******************************************************************************/

#ifndef __IQS7222D_ADDRESSES_H
#define __IQS7222D_ADDRESSES_H

/* Device Information - Read Only */

/* Read Only Version Info */
#define IQS7222D_MM_APP_VERSION_INFO        0x00
#define IQS7222D_MM_APP_VERSION_INFO_1      0x01
#define IQS7222D_MM_APP_VERSION_INFO_2      0x02
#define IQS7222D_MM_APP_VERSION_INFO_3      0x03
#define IQS7222D_MM_APP_VERSION_INFO_4      0x04
#define IQS7222D_MM_APP_VERSION_INFO_5      0x05
#define IQS7222D_MM_ROM_VERSION_INFO        0x06
#define IQS7222D_MM_ROM_VERSION_INFO_1      0x07
#define IQS7222D_MM_ROM_VERSION_INFO_2      0x08
#define IQS7222D_MM_ROM_VERSION_INFO_3      0x09

/* Read Only Device Status */
#define IQS7222D_MM_SYSTEM_STATUS           0x10
#define IQS7222D_MM_EVENTS                  0x11
#define IQS7222D_MM_PROX_EVENT_STATES       0x12
#define IQS7222D_MM_TOUCH_EVENT_STATES      0x13
#define IQS7222D_MM_TRACKPAD_X_OUTPUT       0x14
#define IQS7222D_MM_TRACKPAD_Y_OUTPUT       0x15
#define IQS7222D_MM_TRACKPAD_EVENT_FLAGS    0x16

/* Read Only Channel Counts */
#define IQS7222D_MM_CHANNEL_0_COUNTS        0x20
#define IQS7222D_MM_CHANNEL_1_COUNTS        0x21
#define IQS7222D_MM_CHANNEL_2_COUNTS        0x22
#define IQS7222D_MM_CHANNEL_3_COUNTS        0x23
#define IQS7222D_MM_CHANNEL_4_COUNTS        0x24
#define IQS7222D_MM_CHANNEL_5_COUNTS        0x25
#define IQS7222D_MM_CHANNEL_6_COUNTS        0x26
#define IQS7222D_MM_CHANNEL_7_COUNTS        0x27
#define IQS7222D_MM_CHANNEL_8_COUNTS        0x28
#define IQS7222D_MM_CHANNEL_9_COUNTS        0x29
#define IQS7222D_MM_CHANNEL_10_COUNTS       0x2A
#define IQS7222D_MM_CHANNEL_11_COUNTS       0x2B
#define IQS7222D_MM_CHANNEL_12_COUNTS       0x2C
#define IQS7222D_MM_CHANNEL_13_COUNTS       0x2D

/* Read-Write Channel LTA */
#define IQS7222D_CH0_LTA                    0x30
#define IQS7222D_CH1_LTA                    0x31
#define IQS7222D_CH2_LTA                    0x32
#define IQS7222D_CH3_LTA                    0x33
#define IQS7222D_CH4_LTA                    0x34
#define IQS7222D_CH5_LTA                    0x35
#define IQS7222D_CH6_LTA                    0x36
#define IQS7222D_CH7_LTA                    0x37
#define IQS7222D_CH8_LTA                    0x38
#define IQS7222D_CH9_LTA                    0x39
#define IQS7222D_CH10_LTA                   0x3A
#define IQS7222D_CH11_LTA                   0x3B
#define IQS7222D_CH12_LTA                   0x3C
#define IQS7222D_CH13_LTA                   0x3D

/* Read-Write Cycle Setup */
#define IQS7222D_CYCLE_SETUP0               0x8000
#define IQS7222D_CYCLE_SETUP1               0x8100
#define IQS7222D_CYCLE_SETUP2               0x8200
#define IQS7222D_CYCLE_SETUP3               0x8300
#define IQS7222D_CYCLE_SETUP4               0x8400
#define IQS7222D_CYCLE_SETUP5               0x8500
#define IQS7222D_CYCLE_SETUP6               0x8600

/* Read-Write Global Cycle Setup */
#define IQS7222D_GLOBAL_CYCLE_SETUP         0x8700

/* Read-Write Button Setup - Thresholds, Hysteresis and Debounce */
#define IQS7222D_BUTTON_SETUP0              0x9000
#define IQS7222D_BUTTON_SETUP1              0x9100
#define IQS7222D_BUTTON_SETUP2              0x9200
#define IQS7222D_BUTTON_SETUP3              0x9300
#define IQS7222D_BUTTON_SETUP4              0x9400
#define IQS7222D_BUTTON_SETUP5              0x9500
#define IQS7222D_BUTTON_SETUP6              0x9600
#define IQS7222D_BUTTON_SETUP7              0x9700
#define IQS7222D_BUTTON_SETUP8              0x9800
#define IQS7222D_BUTTON_SETUP9              0x9900
#define IQS7222D_BUTTON_SETUP10             0x9A00
#define IQS7222D_BUTTON_SETUP11             0x9B00
#define IQS7222D_BUTTON_SETUP12             0x9C00
#define IQS7222D_BUTTON_SETUP13             0x9D00

/* Read-Write Channel Setup- ATI Parameters and Rx Select */
#define IQS7222D_CRX_SELECT_GEN_SETUP       0xA000
#define IQS7222D_ATI_BASE_TARGET_CHANNEL0   0xA001
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL0 0xA002
#define IQS7222D_ATI_COMPENSATION_CHANNEL0  0xA003

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL1  0xA100
#define IQS7222D_ATI_BASE_TARGET_CHANNEL1       0xA101
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL1     0xA102
#define IQS7222D_ATI_COMPENSATION_CHANNEL1      0xA103

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL2  0xA200
#define IQS7222D_ATI_BASE_TARGET_CHANNEL2       0xA201
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL2     0xA202
#define IQS7222D_ATI_COMPENSATION_CHANNEL2      0xA203

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL3 0xA300
#define IQS7222D_ATI_BASE_TARGET_CHANNEL3      0xA301
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL3    0xA302
#define IQS7222D_ATI_COMPENSATION_CHANNEL3     0xA303

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL4 0xA400
#define IQS7222D_ATI_BASE_TARGET_CHANNEL4      0xA401
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL4    0xA402
#define IQS7222D_ATI_COMPENSATION_CHANNEL4     0xA403

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL5 0xA500
#define IQS7222D_ATI_BASE_TARGET_CHANNEL5      0xA501
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL5    0xA502
#define IQS7222D_ATI_COMPENSATION_CHANNEL5     0xA503

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL6 0xA600
#define IQS7222D_ATI_BASE_TARGET_CHANNEL6      0xA601
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL6    0xA602
#define IQS7222D_ATI_COMPENSATION_CHANNEL6     0xA603

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL7 0xA700
#define IQS7222D_ATI_BASE_TARGET_CHANNEL7      0xA701
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL7    0xA702
#define IQS7222D_ATI_COMPENSATION_CHANNEL7     0xA703

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL8 0xA800
#define IQS7222D_ATI_BASE_TARGET_CHANNEL8      0xA801
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL8    0xA802
#define IQS7222D_ATI_COMPENSATION_CHANNEL8     0xA803

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL9 0xA900
#define IQS7222D_ATI_BASE_TARGET_CHANNEL9      0xA901
#define IQS7222D_FINE_COARSE_MULTI_CHANNEL9    0xA902
#define IQS7222D_ATI_COMPENSATION_CHANNEL9     0xA903

#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL10     0xAA00
#define IQS7222D_ATI_BASE_TARGET_CHANNEL10          0xAA01
#define IQS7222D_FINE_COARSE_MULTIPLIERS_CHANNEL10  0xAA02
#define IQS7222D_ATI_COMPENSATION_CHANNEL10         0xAA03

/* Read-Write Channel 11 */
#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL11     0xAB00
#define IQS7222D_ATI_BASE_TARGET_CHANNEL11          0xAB01
#define IQS7222D_FINE_COARSE_MULTIPLIERS_CHANNEL11  0xAB02
#define IQS7222D_ATI_COMPENSATION_CHANNEL11         0xAB03

/* Read-Write Channel 12 */
#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL12     0xAC00
#define IQS7222D_ATI_BASE_TARGET_CHANNEL12          0xAC01
#define IQS7222D_FINE_COARSE_MULTIPLIERS_CHANNEL12  0xAC02
#define IQS7222D_ATI_COMPENSATION_CHANNEL12         0xAC03

/* Read-Write Channel 13 */
#define IQS7222D_CRX_SELECT_GEN_SETUP_CHANNEL13     0xAD00
#define IQS7222D_ATI_BASE_TARGET_CHANNEL13          0xAD01
#define IQS7222D_FINE_COARSE_MULTIPLIERS_CHANNEL13  0xAD02
#define IQS7222D_ATI_COMPENSATION_CHANNEL13         0xAD03

/* Read-Write Filter Betas */
#define IQS7222D_FILTER_BETA                  0xAE00
#define IQS7222D_FAST_FILTER_BETA             0xAE01

/* Read-Write Trackpad Setup */
#define IQS7222D_TRACKPAD_GENERAL_SETUP       0xB000
#define IQS7222D_X_Y_LOWER_CALIBRATION        0xB001
#define IQS7222D_X_Y_UPPER_CALIBRATION        0xB002
#define IQS7222D_TOP_BOTTOM_SPEED             0xB003
#define IQS7222D_X_RESOLUTION                 0xB004
#define IQS7222D_Y_RESOLUTION                 0xB005
#define IQS7222D_CHANNEL_ENABLE_MASK          0xB006
#define IQS7222D_ENABLE_STATUS_LINK           0xB007

/* Read-Write Trackpad Delta Links */
#define IQS7222D_DELTA_LINK_0                 0xB008
#define IQS7222D_DELTA_LINK_1                 0xB009
#define IQS7222D_DELTA_LINK_2                 0xB00A
#define IQS7222D_DELTA_LINK_3                 0xB00B
#define IQS7222D_DELTA_LINK_4                 0xB00C
#define IQS7222D_DELTA_LINK_5                 0xB00D
#define IQS7222D_DELTA_LINK_6                 0xB00E
#define IQS7222D_DELTA_LINK_7                 0xB00F
#define IQS7222D_DELTA_LINK_8                 0xB010
#define IQS7222D_DELTA_LINK_9                 0xB011
#define IQS7222D_DELTA_LINK_10                0xB012
#define IQS7222D_DELTA_LINK_11                0xB013

/* Read-Write Trackpad Gestures */
#define IQS7222D_TRACKPAD_GESTURES_0          0xB014
#define IQS7222D_TRACKPAD_GESTURES_1          0xB015
#define IQS7222D_TAP_DISTANCE                 0xB016
#define IQS7222D_SWIPE_DISTANCE               0xB017

/* Read-Write Output Port Pin Settings */
#define IQS7222D_OUTPUT_PORT0_ENABLE_CFG      0xC000
#define IQS7222D_OUTPUT_PORT0_CH_MASK         0xC001
#define IQS7222D_OUTPUT_PORT0_EN_STATUS       0xC002
#define IQS7222D_OUTPUT_PORT1_ENABLE_CFG      0xC100
#define IQS7222D_OUTPUT_PORT1_CH_MASK         0xC101
#define IQS7222D_OUTPUT_PORT1_EN_STATUS       0xC102
#define IQS7222D_OUTPUT_PORT2_ENABLE_CFG      0xC200
#define IQS7222D_OUTPUT_PORT2_CH_MASK         0xC201
#define IQS7222D_OUTPUT_PORT2_EN_STATUS       0xC202

/* Read-Write PMU and System Settings */
#define IQS7222D_CONTROL_SETTINGS             0xD0
#define IQS7222D_ATI_ERROR_TIMEOUT            0xD1
#define IQS7222D_ATI_REPORT_RATE              0xD2
#define IQS7222D_NORM_POWER_MODE_TIMEOUT      0xD3
#define IQS7222D_NORM_POWER_MODE_REPORT       0xD4
#define IQS7222D_LOW_POWER_MODE_TIMEOUT       0xD5
#define IQS7222D_LOW_POWER_MODE_REPORT        0xD6
#define IQS7222D_NORM_POWER_ULP_RATE          0xD7
#define IQS7222D_ULTRA_LOW_POWER_REPORT       0xD8
#define IQS7222D_ULP_ENTRY_MASK               0xD9
#define IQS7222D_EVENT_ENABLE                 0xDA
#define IQS7222D_I2C_COMMUNICATIONS           0xDB
#define IQS7222D_OUTPUT_PORT_OVERRIDE         0xDC
#define IQS7222D_I2C_COMMUNICATIONS_TIMEOUT   0xDD

#endif /* __IQS7222D_ADDRESSES_H */